From 1de947dae4d1a93b5c66627f6883c7eecec7c9f1 Mon Sep 17 00:00:00 2001
From: brinn <brinn>
Date: Sun, 23 Sep 2007 16:36:54 +0000
Subject: [PATCH] doc: improve javadoc

SVN: 1819
---
 .../filesystem/impl/RecursiveHardLinkMaker.java   | 15 ++++++++-------
 .../filesystem/intf/IPathImmutableCopier.java     | 10 ++++++----
 2 files changed, 14 insertions(+), 11 deletions(-)

diff --git a/datamover/source/java/ch/systemsx/cisd/datamover/filesystem/impl/RecursiveHardLinkMaker.java b/datamover/source/java/ch/systemsx/cisd/datamover/filesystem/impl/RecursiveHardLinkMaker.java
index 89836c989ad..c3e5091dc88 100644
--- a/datamover/source/java/ch/systemsx/cisd/datamover/filesystem/impl/RecursiveHardLinkMaker.java
+++ b/datamover/source/java/ch/systemsx/cisd/datamover/filesystem/impl/RecursiveHardLinkMaker.java
@@ -66,22 +66,23 @@ public class RecursiveHardLinkMaker implements IPathImmutableCopier
     }
 
     /**
-     * Copies resource (file or directory) to <code>destinationDirectory</code> by duplicating directory structure and
-     * creating hard link for each file. Note that <code>resource</code> cannot be placed directly inside
-     * <code>destinationDirectory</code>.
+     * Copies <var>code</var> (file or directory) to <var>destinationDirectory</var> by duplicating directory
+     * structure and creating hard link for each file.
+     * <>p>
+     * <i>Note that <var>path</var> cannot be placed directly inside <var>destinationDirectory</var>.<i>
      * 
      * @return pointer to the copied resource or null if copy process failed
      */
-    public File tryCopy(File resource, File destinationDirectory)
+    public File tryCopy(File path, File destinationDirectory)
     {
         if (operationLog.isInfoEnabled())
         {
-            operationLog.info(String.format("Creating a hard link copy of '%s' in '%s'.", resource.getPath(),
+            operationLog.info(String.format("Creating a hard link copy of '%s' in '%s'.", path.getPath(),
                     destinationDirectory.getPath()));
         }
-        String resourceParent = resource.getParentFile().getAbsolutePath();
+        String resourceParent = path.getParentFile().getAbsolutePath();
         assert resourceParent.equals(destinationDirectory.getAbsolutePath()) == false;
-        return tryMakeCopy(resource, destinationDirectory);
+        return tryMakeCopy(path, destinationDirectory);
     }
 
     private File tryMakeCopy(File resource, File destinationDirectory)
diff --git a/datamover/source/java/ch/systemsx/cisd/datamover/filesystem/intf/IPathImmutableCopier.java b/datamover/source/java/ch/systemsx/cisd/datamover/filesystem/intf/IPathImmutableCopier.java
index cafc75def23..e7e25cfb9af 100644
--- a/datamover/source/java/ch/systemsx/cisd/datamover/filesystem/intf/IPathImmutableCopier.java
+++ b/datamover/source/java/ch/systemsx/cisd/datamover/filesystem/intf/IPathImmutableCopier.java
@@ -26,10 +26,12 @@ import java.io.File;
 public interface IPathImmutableCopier
 {
     /**
-     * Creates copy of <code>file</code> in <code>destinationDirectory</code> which should not be modified. Can use
-     * hard links if it is possible.
+     * Creates a copy of <code>path</code> (which may be a file or a directory) in 
+     * <code>destinationDirectory</code>, which must not be modified later.
+     * <p>
+     * <i>Can use hard links if available.</i>
      * 
      * @return pointer to the created file or <code>null</code> if operation failed
      */
-    File tryCopy(File file, File destinationDirectory);
+    File tryCopy(File path, File destinationDirectory);
 }
@@ -26,10 +26,12 @@ import java.io.File;
      * 
-     * @return pointer to the created file or <code>null</code> if operation failed
+     * @return the new path created, or <code>null</code> if the operation fails
      */
-- 
GitLab